@@ -8,7 +8,6 @@ import subprocess
 import re
 
 from catsnap import Client
-from catsnap.config import MetaConfig
 
 class ImageTruck():
     def __init__(self, contents, content_type, source_url):
@@ -35,6 +34,11 @@ class ImageTruck():
 
         return cls(contents, 'image/'+filetype, None)
 
+    @classmethod
+    def new_from_stream(cls, stream, content_type):
+        contents = stream.read()
+        return cls(contents, content_type, None)
+
     @classmethod
     def new_from_something(cls, path):
         url = requests.utils.urlparse(path)
@@ -45,8 +49,7 @@ class ImageTruck():
 
     @classmethod
     def url_for_filename(cls, filename):
-        return cls._url(filename, MetaConfig().bucket,
-                extension=MetaConfig().extension)
+        return cls._url(filename, Client().config().bucket)
 
     def upload(self):
         key = Client().bucket().new_key(self.calculate_filename())
@@ -60,13 +63,16 @@ class ImageTruck():
         return hashlib.sha1(self.contents).hexdigest()
 
     def url(self, **kwargs):
-        return self._url(self.calculate_filename(), MetaConfig().bucket,
-                extension=MetaConfig().extension)
+        return self._url(self.calculate_filename(), Client().config().bucket)
 
     @classmethod
-    def _url(cls, filename, bucket_name, extension=False):
+    def _url(cls, filename, bucket_name):
         url = 'https://s3.amazonaws.com/%(bucket)s/%(filename)s' % {
                 'bucket': bucket_name, 'filename': filename}
-        if extension:
-            url = url + '#.gif'
+        return cls.extensioned(url)
+
+    @classmethod
+    def extensioned(cls, url):
+        if Client().config().extension:
+            url += '#.gif'
         return url
